@@ -30,6 +30,7 @@ THE SOFTWARE.
 
 import re
 import os
+from pprint import pprint
 from bs4 import BeautifulSoup
 from lendingclub.filters import Filter, FilterByLoanID, SavedFilter
 from lendingclub.session import Session
@@ -376,7 +377,7 @@ class LendingClub:
 
         return False
 
-    def build_portfolio(self, cash, max_per_note=25, min_percent=0, max_percent=20, filters=None, automatically_invest=False):
+    def build_portfolio(self, cash, max_per_note=25, min_percent=0, max_percent=20, filters=None, automatically_invest=False, do_not_clear_staging=False):
         """
         Returns a list of loan notes that are diversified by your min/max percent request and filters.
         One way to invest in these loan notes, is to start an order and use add_batch to add all the
@@ -397,6 +398,9 @@ class LendingClub:
         automatically_invest : boolean, optional
             If you want the tool to create an order and automatically invest in the portfolio that matches your filter.
             (default False)
+        do_not_clear_staging : boolean, optional
+            Similar to automatically_invest, don't do this unless you know what you're doing.
+            Setting this to True stops the method from clearing the loan staging area before returning
 
         Returns
         -------
@@ -439,8 +443,9 @@ class LendingClub:
 
             >>> len(portfolio['loan_fractions'])    # See how many loans are in this portfolio
             16
+            >>> loans_notes = portfolio['loan_fractions']
             >>> order = lc.start_order()            # Start a new order
-            >>> order.add_batch(portfolio)          # Add the portfolio to the order
+            >>> order.add_batch(loans_notes)        # Add the loan notes to the order
             >>> order.execute()                     # Execute the order
             1861880
 
@@ -562,7 +567,8 @@ class LendingClub:
 
             # Not investing -- reset portfolio search session and return
             if automatically_invest is not True:
-                self.session.clear_session_order()
+                if do_not_clear_staging is not True:
+                    self.session.clear_session_order()
 
             # Invest in this porfolio
             elif automatically_invest is True:  # just to be sure
@@ -664,15 +670,15 @@ class LendingClub:
             >>> lc = LendingClub(email='test@test.com', password='secret123')
             >>> lc.authenticate()
             True
-            >>> notes = lc.get_notes()                  # Get the first 100 loan notes
+            >>> notes = lc.my_notes()                  # Get the first 100 loan notes
             >>> len(notes['loans'])
             100
             >>> notes['total']                          # See the total number of loan notes you have
             630
-            >>> notes = lc.get_notes(start_index=100)   # Get the next 100 loan notes
+            >>> notes = lc.my_notes(start_index=100)   # Get the next 100 loan notes
             >>> len(notes['loans'])
             100
-            >>> notes = lc.get_notes(get_all=True)       # Get all notes in one request (may be slow)
+            >>> notes = lc.my_notes(get_all=True)       # Get all notes in one request (may be slow)
             >>> len(notes['loans'])
             630
         """
@@ -963,7 +969,7 @@ class Order:
         assert batch_amount is None or batch_amount % 25 == 0, 'batch_amount must be a multiple of 25'
 
         # Add each loan
-        assert type(loans) is list, 'The loans property must be a list'
+        assert type(loans) is list, 'The loans property must be a list. (not {0})'.format(type(loans))
         for loan in loans:
             loan_id = loan
             amount = batch_amount
@@ -1089,7 +1095,7 @@ class Order:
         if len(results['loans']) == 0 or results['totalRecords'] != len(self.loans):
             raise LendingClubError('Could not stage the loans. The number of loans in your batch does not match totalRecords. {0} != {1}'.format(len(self.loans), results['totalRecords']), results)
 
-        # Stage all loans
+        # Stage each loan
         for loan_id, amount in self.loans.iteritems():
             payload = {
                 'method': 'addToPortfolio',
@@ -1135,8 +1141,8 @@ class Order:
             if strut_tag and strut_tag['value'].strip():
                 return strut_tag['value'].strip()
             else:
-                self.__log('No struts token! {0}', response.text)
-                raise LendingClubError('Could not find the struts token to place order with', response)
+                self.__log('No struts token! HTML: {0}'.format(response.text))
+                raise LendingClubError('No struts token', response)
 
         except Exception as e:
             self.__log('Could not get struts token. Error message: {0}'.format(str(e)))
